import { ICreatePaymentOptions, IPaymentFormResponse, IPaymentInfoResponse, IPaymentListOptions, IPaymentListResponse, IResendWebhookResponse, ITransferToWallet, ITransferToWalletResponse, IRefundResponse, IBalanceResponse } from './interfaces/payment.interface';
import { IBlockWalletResponse, IWalletOptions, IWalletResponse } from './interfaces/wallet.interface';
import { IServicesResponse } from './interfaces/services.interface';
import { IPayoutInfoResponse, IPayoutListResponse, IPayoutOptions, IPayoutResponse } from './interfaces/payout.interface';
import { FindByOptions, FindRefundOptions, FindWalletOptions } from './types/findByOptions.type';
export declare class Cryptomus {
    private readonly merchant;
    private readonly paymentKey;
    private readonly payoutKey;
    private readonly url;
    constructor(merchant: string, paymentKey: string, payoutKey: string);
    private requestBuilder;
    createPayment(paymentOptions: ICreatePaymentOptions): Promise<IPaymentFormResponse>;
    getPaymentInfo(options: FindByOptions): Promise<IPaymentInfoResponse>;
    getPaymentHistory(paymentListOptions?: IPaymentListOptions, cursor?: string): Promise<IPaymentListResponse>;
    getPaymentServices(): Promise<IServicesResponse>;
    refund(refundOptions: FindRefundOptions): Promise<IRefundResponse>;
    getBalance(): Promise<IBalanceResponse>;
    resendWebhook(resendOptions: FindByOptions): Promise<IResendWebhookResponse>;
    createWallet(walletOptions: IWalletOptions): Promise<IWalletResponse>;
    blockWallet(walletOptions: FindWalletOptions): Promise<IBlockWalletResponse>;
    createPayout(payoutOptions: IPayoutOptions): Promise<IPayoutResponse>;
    getPayoutInfo(payoutInfoOptions: FindByOptions): Promise<IPayoutInfoResponse>;
    getPayoutHistory(cursor?: string): Promise<IPayoutListResponse>;
    getPayoutServices(): Promise<IServicesResponse>;
    transferToWallet(walletType: 'personal' | 'business', transferOption: ITransferToWallet): Promise<ITransferToWalletResponse>;
    generateUUID(): string;
    generateShortUUID(): string;
}
